#!/usr/bin/env python
# -*- coding: utf_8 -*-

import uuid
from datetime import datetime
from pony.orm import PrimaryKey, Required, Optional, Set, LongStr, Json
from app import config
from . import fullStackDB

db = fullStackDB.db

class Summary(db.Entity):
    _table_ = "{}".format(config['TABLE_PREFIX']) + "summary"
    id = PrimaryKey(int, auto=True)
    uuid = Required(uuid.UUID, unique=True, default=uuid.uuid1, index=True)
    name = Required(str, max_len=200) # 总结标题
    year_supervise_churn_rate = Required(float) # 年度监督流失率
    year_recert_churn_rate = Required(float) # 年度再认证流失率
    year_satis_churn_rate = Required(float) # 年度顾客满意率
    year_dispatch_site_days = Required(int) # 年度调派技术现场总人天数
    year_receiv_collection_rate = Required(float) # 年度应收款回款率
    year_bad_project = Required(int) # 年度列入坏账并终止项目数
    year_bad_debt_amount = Required(float) # 年度坏账金额
    indus_project_rate = Required(float) # 行业项目比率
    indus_project_count = Required(int) # 行业项目数量
    channel_project_rate = Required(float) # 渠道开发项目比率
    channel_project_count = Required(int) # 渠道开发项目数量
    create_at = Required(datetime, default=datetime.now)
    create_by = Required("User", reverse='summary_creator') # Summary与User一对一关系
    update_at = Required(datetime, default=datetime.now)
    update_by = Required("User", reverse='summary_updater') # Summary与User一对一关系
    delete_at = Optional(datetime)
    delete_by = Optional("User", reverse='summary_deleter') # Summary与User一对一关系
    is_delete = Required(bool, default=False)
    sort = Optional(int, size=32, default=0)
    remarks = Optional(str, max_len=255, default="", nullable=True)